@@ -4,6 +4,7 @@ from common.logging_config import logger
 from common.rest_extend.response import Results, PageTypeResults, SERVER_ERROR_CODE
 from elasticsearch import Elasticsearch
 from common.utility.args_parsing import BaseArgsParsing
+from common.utility.base import convert_time
 
 
 class ESClient(BaseArgsParsing):
@@ -185,6 +186,9 @@ class ESClient(BaseArgsParsing):
             for item in es_results["hits"]["hits"]:
                 try:
                     _source = item["_source"]
+                    _time = _source['time']
+                    _time = convert_time(_time)
+                    _source['time'] = _time
                     page_type_results.result.append(_source)
                 except Exception as e:
                     logger.exception(e)
